@@ -93,7 +93,8 @@ def wrap_iter(
                     break
     except BaseException as e:
         if callable(callexit):
-            callexit(it, e)
+            if not callexit(it, e):
+                raise
         else:
             raise
     finally:
